from distutils.core import setup

setup(
    name='Elpotrero',
    version='1.2',
    packages=['elpotrero', 'elpotrero.lib', ],
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('README.txt').read(),
)
